package jalview.gui;

import java.net.URL;

import javax.help.HelpBroker;
import javax.help.HelpSet;
import javax.help.HelpSetException;

/**
 * Utility class to show the help documentation window.
 * 
 * @author gmcarstairs
 *
 */
public class Help
{

  private static final long HALF_A_MO = 500; // half a second

  private static long lastOpenedTime = 0L;

  /**
   * Not instantiable
   */
  private Help()
  {

  }

  /**
   * Show help text in a new window. But do nothing if within half a second of
   * the last invocation.
   * 
   * This is a workaround for issue JAL-914 - both Desktop and AlignFrame
   * responding to F1 key, resulting in duplicate help windows opened.
   * 
   * @throws HelpSetException
   */
  public static void showHelpWindow() throws HelpSetException
  {
    long timeNow = System.currentTimeMillis();

    if (timeNow - lastOpenedTime > HALF_A_MO)
    {
      lastOpenedTime = timeNow;
      ClassLoader cl = Desktop.class.getClassLoader();
      URL url = HelpSet.findHelpSet(cl, "help/help"); // $NON-NLS-$
      HelpSet hs = new HelpSet(cl, url);

      HelpBroker hb = hs.createHelpBroker();
      hb.setCurrentID("home");
      hb.setDisplayed(true);
    }
  }
}
